@@ -8,7 +8,7 @@ use base 'Test::More';
 use Test::More;
 use Term::ANSIColor qw(colored);
 
-use version; our $VERSION = qv('0.4.2');
+use version; our $VERSION = qv('0.4.3');
 
 our @EXPORT = ( @Test::More::EXPORT, qw(describe context it) );
 
@@ -122,9 +122,9 @@ Test::More::Behaviour - BDD module for Perl
 
 =head1 DESCRIPTION
 
-Test::More::Behaviour is a Behaviour-Driven Development module for Perl programmers.  It is modeled after Rspec (http://rspec.info) the infamous BDD tool for Ruby programmers.
+Test::More::Behaviour is a Behaviour-Driven Development module for Perl programmers.  It is modeled after Rspec (F<http://rspec.info>) the infamous BDD tool for Ruby programmers.
 
-Since Test::More::Behaviour uses Test::More as its 'base', you can treat every Test::More::Behaviour test as if it were Test::More!
+Because Test::More::Behaviour uses Test::More as its 'base', you can treat every Test::More::Behaviour test as if it were Test::More!
 
 =head1 QUICK REFERENCE
 
@@ -143,15 +143,18 @@ An example to run.
 Use this to further establish deeper relations for a set of examples.  This is best used when several examples have similar interactions with the system but have differring expectations.
 
 =item B<before_all>
+
 =item B<before_each>
+
 =item B<after_each>
+
 =item B<after_all>
 
 You can use these to define code which executes before and after each example or only once per example group.
 
 =head1 SOURCE
 
-The source code for Test::More::Behaviour can be found at https://github.com/bostonaholic/test-more-behaviour
+The source code for Test::More::Behaviour can be found at F<https://github.com/bostonaholic/test-more-behaviour>
 
 =head1 KNOWN BUGS
 
@@ -160,8 +163,11 @@ None, yet.  But please, send me an email or send me a github pull request with a
 =head1 DEPENDENCIES
 
 L<Test::More>
+
 L<Term::ANSIColor>
+
 L<version>
+
 L<IO::Capture::Stdout> (test only)
 
 =head1 AUTHOR
